package com.example;

import java.io.File;
import java.io.FileOutputStream;
import java.io.InputStream;

import org.apache.cordova.CallbackContext;
import org.apache.cordova.CordovaInterface;
import org.apache.cordova.CordovaPlugin;
import org.apache.cordova.CordovaWebView;
import org.apache.cordova.PluginResult;
import org.json.JSONArray;
import org.json.JSONException;

import android.app.Activity;
import android.content.Intent;
import android.database.Cursor;
import android.net.Uri;
import android.provider.MediaStore;
import android.util.Log;


public class NewFilePicker extends CordovaPlugin {
    private static final String TAG = "MyCordovaPlugin";

    public static final int FILE_PICKER = 7766;

    public void initialize(CordovaInterface cordova, CordovaWebView webView) {
        super.initialize(cordova, webView);

        Log.d(TAG, "Initializing MyCordovaPlugin");

        cordova.setActivityResultCallback(this);


    }

    private CallbackContext callbackCtx;

    @Override
    public void onActivityResult(int requestCode, int resultCode, Intent intent) {
        if (requestCode == FILE_PICKER) {
            if (resultCode == Activity.RESULT_OK) {
                Uri data = intent.getData();
                NewFilePicker thisPlugin = NewFilePicker.this;
                String path = thisPlugin.copyFileToInternalStorage(data, "saved");
                final PluginResult res = new PluginResult(PluginResult.Status.OK, path);
                callbackCtx.sendPluginResult(res);
            } else {
                final PluginResult res = new PluginResult(PluginResult.Status.ERROR, "Cancelled by user");
                callbackCtx.sendPluginResult(res);
            }
        }
    }

    public boolean execute(String action, JSONArray args, final CallbackContext callbackContext) throws JSONException {
        if (action.equals("pickFile")) {
            Log.d(TAG, "Entrou");
            String type = args.getString(0);
            String[] mimeTypes = args.getString(1).split(",");
            Log.d(TAG, type);
            for (String mimeType : mimeTypes) {
                Log.d(TAG, mimeType);
            }

            Intent intent = new Intent();

            intent.setType(type);

            intent.putExtra(
                    Intent.EXTRA_MIME_TYPES,
                    mimeTypes
            );

            intent.setAction(Intent.ACTION_GET_CONTENT);
            callbackCtx = callbackContext;
            cordova.startActivityForResult(this, intent, FILE_PICKER);
        } else if(action.equals("recordVideo")){
            Intent intent = new Intent(MediaStore.ACTION_VIDEO_CAPTURE);
            callbackCtx = callbackContext;
            cordova.startActivityForResult(this, intent, FILE_PICKER);
        }
        return true;
    }

    private final String copyFileToInternalStorage(Uri uri, String newDirName) {
        Activity activity = cordova.getActivity();
        Cursor returnCursor = activity
                .getContentResolver().query(uri,
                        new String[]{"_display_name", "_size"},
                        null,
                        null,
                        null
                );

        int nameIndex = returnCursor.getColumnIndex("_display_name");
        int sizeIndex = returnCursor.getColumnIndex("_size");
        returnCursor.moveToFirst();
        String name = returnCursor.getString(nameIndex);
        String size = Long.toString(returnCursor.getLong(sizeIndex));
        File output = null;
        if (newDirName == "") {
            File dir = new File(activity.getFilesDir().toString() + "/" + newDirName);
            if (!dir.exists()) {
                dir.mkdir();
            }

            output = new File(activity.getFilesDir().toString() + "/" + newDirName + "/" + name);
        } else {
            output = new File(activity.getFilesDir().toString() + "/" + name);
        }

        try {
            InputStream var21 = activity.getContentResolver().openInputStream(uri);
            InputStream inputStream = var21;
            FileOutputStream outputStream = new FileOutputStream(output);
            int bufferSize = 1024;
            byte[] buffers = new byte[bufferSize];

            while (true) {
                int var14 = inputStream.read(buffers);

                if (var14 == -1) {
                    inputStream.close();
                    outputStream.close();
                    break;
                }

                outputStream.write(buffers, 0, var14);
            }
        } catch (Exception var19) {
            String var10001 = var19.getMessage();
            Log.e("Exception", var10001);
        }

        return output.getPath();
    }


}